@@ -30,7 +30,7 @@ class CustomerMarketing(Fairness):
                 Data holder that contains all the attributes of the model to be assessed. Compulsory input for initialization.
                 If a single object is provided, it will be taken as either a "rejection" or "propensity" model according to the model_type flag.
                 If 2 objects are provided, while the model_type flag is "uplift", the first one corresponds to rejection model while the second one corresponds to propensity model.
-                **x_train[0] = x_test[1] and x_test[0]=x_test[1] must be the same when len(model_param) > 1
+                **x_train[0] = x_train[1] and x_test[0]=x_test[1] must be the same when len(model_param) > 1
 
         fair_threshold: int or float
                 Value between 0 and 100. If a float between 0 and 1 (not inclusive) is provided, it is used to benchmark against the primary fairness metric value to determine the fairness_conclusion.
@@ -151,7 +151,7 @@ class CustomerMarketing(Fairness):
             "fairness_metric_value_input":[(dict,), None]}
 
         self.k = Constants().k
-        self.array_size = Constants().array_size
+        self.array_size = Constants().perf_dynamics_array_size
         self.decimals = Constants().decimals
 
         if self.model_params[0].model_type == "uplift":
@@ -168,19 +168,24 @@ class CustomerMarketing(Fairness):
         Wrapper function to perform all checks using dictionaries of datatypes & dictionary of values.
         This function does not return any value. Instead, it raises an error when any of the checks from the Utility class fail.
         """
+        #import error class
         err = VeritasError()
+        #check datatype of input variables to ensure they are of the correct datatype
         check_datatype(self)
 
+        #check datatype of input variables to ensure they are reasonable
         check_value(self)
 
-        # Check for length of model_params
+        #check for length of model_params
         mp_g = len(self.model_params)
         mp_e = self._model_type_to_metric_lookup[self.model_params[0].model_type][2]
         if mp_g != mp_e:
             err.push('length_error', var_name="model_params", given=str(mp_g), expected= str(mp_e), function_name="_check_input")
 
+        #check for conflicting input values
         self._base_input_check()
 
+        #check if input variables will the correct fair_metric_name based on fairness tree
         self._fairness_metric_value_input_check()
 
         #check for y_prob not None if model is uplift, else check for y_pred not None
@@ -193,35 +198,40 @@ class CustomerMarketing(Fairness):
                 if self.model_params[i].y_pred is None:
                     err.push('type_error', var_name="y_pred", given= "type None", expected="type [list, np.ndarray, pd.Series]", function_name="_check_input")
 
+        #check for y_pred not None if model is uplift, if yes set to None as it is not required
         if self.model_params[0].model_type == 'uplift' and self.model_params[0].y_pred is not None:
             for i in range(len(self.model_params)):
                 self.model_params[i].y_pred = None
         
+        #check for y_prob is not None, if not None it cannot be an integer
         if self.model_params[0].y_prob is not None:
             if self.model_params[0].y_prob.dtype.kind == "i":
                 err.push('type_error', var_name="y_prob", given= "type int", expected="type float", function_name="_check_input")
 
-        #Check for revenue and treatment_cost
+        #check for revenue and treatment_cost
+        #only for uplift models based on expected profit perf metric        
         if self.model_params[0].model_type == 'uplift' and self.perf_metric_name == "expected_profit":
             exp_type = list((int, float))
             spl_range = (0, np.inf)
+            #check if spl params are in expected type, otherwise throw exception
             for i in self.spl_params.keys() :
                 if type(self.spl_params[i]) not in exp_type :
                     err.push('type_error', var_name=str(i), given=type(self.spl_params[i]), expected=exp_type, function_name="_check_input")
-
+                #check if spl params are within expected range, otherwise throw exception
                 try:
                     if type(self.spl_params[i]) != type(None):
                         if  self.spl_params[i] < spl_range[0]  or self.spl_params[i] > spl_range[1] :
                             err.push('value_error', var_name=str(i), given=self.spl_params[i],  expected="range " + str(spl_range), function_name="_check_input")
                 except:
                     pass
+            #check if in spl params, revenue value provided is not less than treatment_cost 
             try:
                 if self.spl_params['revenue'] < self.spl_params['treatment_cost']:
                     err.push('value_error_compare', var_name_a="revenue", var_name_b="treatment_cost", function_name="_check_input")
             except:
                 pass
         
-        
+        #print any exceptions occured        
         err.pop()
     
     def _get_confusion_matrix(self, y_true, y_pred, sample_weight, curr_p_var = None, feature_mask = None, **kwargs):
@@ -250,6 +260,7 @@ class CustomerMarketing(Fairness):
         -------
         Confusion matrix metrics based on privileged and unprivileged groups or a list of None if curr_p_var == None
         """
+        #confusion matrix will only run for classification models
         if self._model_type_to_metric_lookup[self.model_params[0].model_type][0] == "classification" :
             if 'y_true' in kwargs:
                 y_true = kwargs['y_true']
@@ -293,6 +304,7 @@ class CustomerMarketing(Fairness):
         Retrieves the fairness metric name based on the values of model_type, fair_concern, fair_impact and fair_priority.
         Name of the primary fairness metric to be used for computations in the evaluate() and/or compile() functions                
         """
+        #if model type is uplift, will not use fairness_tree
         if self.fair_metric_name == 'auto':
             if self.model_params[0].model_type == 'uplift':
                 self.fair_metric_name = 'rejected_harm'
@@ -319,7 +331,7 @@ class CustomerMarketing(Fairness):
         e_lift : float or None
             Empirical lift value
         """
-
+        #e_lift will only run for uplift models
         if self.model_params[0].model_type == 'uplift':
             
             y_train = self.model_params[1].y_train
@@ -357,7 +369,7 @@ class CustomerMarketing(Fairness):
         pred_outcome : dictionary
                 Contains the probabilities of the treatment and control groups for both rejection and acquiring
         """
-
+        #pred_outcome will only run for uplift models
         if self.model_params[0].model_type == 'uplift':
 
             y_prob = [model.y_prob for model in self.model_params]
